# HackerType
Type fast like a true holywood movie hacker

```
Usage: hackertype.py [OPTIONS] INPUT_FILE

Options:
  -s, --speed INTEGER RANGE  Typing speed (characters per keypress)
  --skip INTEGER RANGE       Skip first N lines
  --loop / --no-loop         Loop over the input file infinitely
  --help                     Show this message and exit.
```